'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var fs = require('fs');
var rollupPluginutils = require('rollup-pluginutils');

function css (options) {
  if ( options === void 0 ) options = {};

  var filter = rollupPluginutils.createFilter(options.include || ['**/*.css'], options.exclude)
  var styles = {}
  var dest = options.output
  var changes = 0

  return {
    name: 'css',
    transform: function transform (code, id) {
      if (!filter(id)) {
        return
      }

      // When output is disabled, the stylesheet is exported as a string
      if (options.output === false) {
        return {
          code: 'export default ' + JSON.stringify(code),
          map: { mappings: '' }
        }
      }

      // Keep track of every stylesheet
      // Check if it changed since last render
      if (styles[id] !== code && (styles[id] || code)) {
        styles[id] = code
        changes++
      }

      return ''
    },
    ongenerate: function ongenerate (opts, rendered) {
      // No stylesheet needed
      if (!changes || options.output === false) {
        return
      }
      changes = 0

      // Combine all stylesheets
      var css = ''
      for (var id in styles) {
        css += styles[id] || ''
      }

      // Emit styles through callback
      if (typeof options.output === 'function') {
        options.output(css, styles)
        return
      }

      if (typeof dest !== 'string') {
        // Don't create unwanted empty stylesheets
        if (!css.length) {
          return
        }

        // Guess destination filename
        dest = opts.dest || 'bundle.js'
        if (dest.endsWith('.js')) {
          dest = dest.slice(0, -3)
        }
        dest = dest + '.css'
      }

      // Emit styles to file
      fs.writeFile(dest, css, function (err) {
        if (err) {
          throw err
        }
        emitted(dest, css.length)
      })
    }
  }
}

function emitted (text, bytes) {
  console.log(green(text), getSize(bytes))
}

function green (text) {
  return '\u001b[1m\u001b[32m' + text + '\u001b[39m\u001b[22m'
}

function getSize (bytes) {
  return bytes < 10000
    ? bytes.toFixed(0) + ' B'
    : bytes < 1024000
    ? (bytes / 1024).toPrecision(3) + ' kB'
    : (bytes / 1024 / 1024).toPrecision(4) + ' MB'
}

exports['default'] = css;
exports.emitted = emitted;
exports.green = green;
exports.getSize = getSize;